@@ -15,15 +15,17 @@ from .catalog import catalog_list
 from .config import Config, Migration, parse_dynamic_facts_from_cli
 from .helpers import clean_working_tree
 from .compile import compile as _compile
-from .component.template import ComponentTemplater
+from .component import Component
 from .component.compile import compile_component
+from .component.template import ComponentTemplater
+from .dependency_syncer import sync_dependencies
 from .inventory.render import extract_components, extract_packages, extract_parameters
 from .inventory.parameters import InventoryFacts
 from .inventory.lint import LINTERS
 from .login import login, fetch_token
+from .package import Package
 from .package.compile import compile_package
 from .package.template import PackageTemplater
-from .package.sync import sync_packages
 
 pass_config = click.make_pass_decorator(Config)
 
@@ -335,30 +337,179 @@ def component(config: Config, verbose):
     show_default=True,
     help="Enable test matrix for compile/golden tests.",
 )
+@click.option(
+    "--output-dir",
+    default="",
+    show_default=True,
+    type=click.Path(file_okay=False, dir_okay=True),
+    help="The directory in which to place the new component.",
+)
+@click.option(
+    "--template-url",
+    default="https://github.com/projectsyn/commodore-component-template.git",
+    show_default=True,
+    help="The URL of the component cookiecutter template.",
+)
+@click.option(
+    "--template-version",
+    default="main",
+    show_default=True,
+    help="The component template version (Git tree-ish) to use.",
+)
+@click.option(
+    "--additional-test-case",
+    "-t",
+    metavar="CASE",
+    default=[],
+    show_default=True,
+    multiple=True,
+    help="Additional test cases to generate in the new component. Can be repeated. "
+    + "Test case `defaults` will always be generated."
+    + "Commodore will deduplicate test cases by name.",
+)
 @verbosity
 @pass_config
 # pylint: disable=too-many-arguments
 def component_new(
     config: Config,
-    slug,
-    name,
-    lib,
-    pp,
-    owner,
-    copyright_holder,
-    golden_tests,
-    matrix_tests,
-    verbose,
+    slug: str,
+    name: str,
+    lib: bool,
+    pp: bool,
+    owner: str,
+    copyright_holder: str,
+    golden_tests: bool,
+    matrix_tests: bool,
+    verbose: int,
+    output_dir: str,
+    template_url: str,
+    template_version: str,
+    additional_test_case: Iterable[str],
 ):
     config.update_verbosity(verbose)
-    f = ComponentTemplater(config, slug, name=name)
-    f.library = lib
-    f.post_process = pp
-    f.github_owner = owner
-    f.copyright_holder = copyright_holder
-    f.golden_tests = golden_tests
-    f.matrix_tests = matrix_tests
-    f.create()
+    t = ComponentTemplater(
+        config, template_url, template_version, slug, name=name, output_dir=output_dir
+    )
+    t.library = lib
+    t.post_process = pp
+    t.github_owner = owner
+    t.copyright_holder = copyright_holder
+    t.golden_tests = golden_tests
+    t.matrix_tests = matrix_tests
+    t.test_cases = ["defaults"] + list(additional_test_case)
+    t.create()
+
+
+@component.command(
+    name="update", short_help="Update an existing component from a template"
+)
+@click.argument(
+    "component_path", type=click.Path(exists=True, dir_okay=True, file_okay=False)
+)
+@click.option(
+    "--copyright",
+    "copyright_holder",
+    show_default=True,
+    help="Update the copyright holder in the license file.",
+)
+@click.option(
+    "--update-copyright-year/--no-update-copyright-year",
+    default=False,
+    show_default=True,
+    help="Update year in copyright notice.",
+)
+@click.option(
+    "--golden-tests/--no-golden-tests",
+    default=None,
+    show_default=True,
+    help="Add or remove golden tests.",
+)
+@click.option(
+    "--matrix-tests/--no-matrix-tests",
+    default=None,
+    show_default=True,
+    help="Add or remove matrix tests.",
+)
+@click.option(
+    "--lib/--no-lib",
+    default=None,
+    show_default=True,
+    help="Add or remove the component library.",
+)
+@click.option(
+    "--pp/--no-pp",
+    default=None,
+    show_default=True,
+    help="Add or remove the postprocessing filter configuration.",
+)
+@click.option(
+    "--additional-test-case",
+    "-t",
+    metavar="CASE",
+    default=[],
+    show_default=True,
+    multiple=True,
+    help="Additional test cases to add to the component. Can be repeated. "
+    + "Commodore will deduplicate test cases by name.",
+)
+@click.option(
+    "--remove-test-case",
+    metavar="CASE",
+    default=[],
+    show_default=True,
+    multiple=True,
+    help="Test cases to remove from the package. Can be repeated.",
+)
+@click.option(
+    "--commit / --no-commit",
+    is_flag=True,
+    default=True,
+    help="Whether to commit the rendered template changes.",
+)
+@verbosity
+@pass_config
+def component_update(
+    config: Config,
+    verbose: int,
+    component_path: str,
+    copyright_holder: str,
+    golden_tests: Optional[bool],
+    matrix_tests: Optional[bool],
+    lib: Optional[bool],
+    pp: Optional[bool],
+    update_copyright_year: bool,
+    additional_test_case: Iterable[str],
+    remove_test_case: Iterable[str],
+    commit: bool,
+):
+    """This command updates the component at COMPONENT_PATH to the latest version of the
+    template which was originally used to create it, if the template version is given as
+    a Git branch.
+
+    The command can also add or remove component features, based on the provided command
+    line options.
+    """
+    config.update_verbosity(verbose)
+
+    t = ComponentTemplater.from_existing(config, Path(component_path))
+    if copyright_holder:
+        t.copyright_holder = copyright_holder
+    if update_copyright_year:
+        t.copyright_year = None
+    if golden_tests is not None:
+        t.golden_tests = golden_tests
+    if matrix_tests is not None:
+        t.matrix_tests = matrix_tests
+    if lib is not None:
+        t.library = lib
+    if pp is not None:
+        t.post_process = pp
+
+    test_cases = t.test_cases
+    test_cases.extend(additional_test_case)
+    t.test_cases = [tc for tc in test_cases if tc not in remove_test_case]
+
+    t.update(commit=commit)
 
 
 @component.command(name="delete", short_help="Remove component from inventory.")
@@ -375,7 +526,7 @@ def component_new(
 def component_delete(config: Config, slug, force, verbose):
     config.update_verbosity(verbose)
     config.force = force
-    f = ComponentTemplater(config, slug)
+    f = ComponentTemplater(config, "", None, slug)
     f.delete()
 
 
@@ -448,6 +599,80 @@ def component_compile(
     compile_component(config, path, alias, values, search_paths, output, name)
 
 
+@component.command("sync", short_help="Synchronize components to template")
+@verbosity
+@pass_config
+@click.argument(
+    "component_list", type=click.Path(file_okay=True, dir_okay=False, exists=True)
+)
+@click.option(
+    "--github-token",
+    help="GitHub API token",
+    envvar="COMMODORE_GITHUB_TOKEN",
+    default="",
+)
+@click.option(
+    "--dry-run",
+    is_flag=True,
+    help="Don't commit rendered changes or create or update PRs",
+    default=False,
+)
+@click.option(
+    "--pr-branch",
+    "-b",
+    metavar="BRANCH",
+    default="template-sync",
+    type=str,
+    help="Branch name to use for updates from template",
+)
+@click.option(
+    "--pr-label",
+    "-l",
+    metavar="LABEL",
+    default=[],
+    multiple=True,
+    help="Labels to set on the PR. Can be repeated",
+)
+def component_sync(
+    config: Config,
+    verbose: int,
+    component_list: str,
+    github_token: str,
+    dry_run: bool,
+    pr_branch: str,
+    pr_label: Iterable[str],
+):
+    """This command processes all components listed in the provided `COMPONENT_LIST`
+    YAML file.
+
+    Currently, the command only supports updating components hosted on GitHub. The
+    command expects that the YAML file contains a single document with a list of GitHub
+    repositories in form `organization/repository-name`.
+
+    The command clones each component and runs `component update` on the local copy. If
+    there are any changes, the command creates a PR for the changes. For each component,
+    the command parses the component's `.cruft.json` to determine the template repository
+    and template version for the component. The command bases each PR on the default
+    branch of the corresponding component repository as reported by the GitHub API.
+
+    The command requires a GitHub Access token with the 'public_repo' permission, which
+    is required to create PRs on public repositories. If you want to manage private
+    repos, the access token may require additional permissions.
+    """
+    config.update_verbosity(verbose)
+    config.github_token = github_token
+
+    sync_dependencies(
+        config,
+        Path(component_list),
+        dry_run,
+        pr_branch,
+        pr_label,
+        Component,
+        ComponentTemplater,
+    )
+
+
 @commodore.group(short_help="Interact with a Commodore config package")
 @verbosity
 @pass_config
@@ -533,12 +758,12 @@ def package_new(
     to configure golden tests, and the licensing details.
     """
     config.update_verbosity(verbose)
-    t = PackageTemplater(config, slug, name=name, output_dir=output_dir)
+    t = PackageTemplater(
+        config, template_url, template_version, slug, name=name, output_dir=output_dir
+    )
     t.github_owner = owner
     t.copyright_holder = copyright_holder
     t.golden_tests = golden_tests
-    t.template_url = template_url
-    t.template_version = template_version
     t.test_cases = ["defaults"] + list(additional_test_case)
     t.create()
 
@@ -586,6 +811,12 @@ def package_new(
     multiple=True,
     help="Test cases to remove from the package. Can be repeated.",
 )
+@click.option(
+    "--commit / --no-commit",
+    is_flag=True,
+    default=True,
+    help="Whether to commit the rendered template changes.",
+)
 @verbosity
 @pass_config
 # pylint: disable=too-many-arguments
@@ -598,6 +829,7 @@ def package_update(
     update_copyright_year: bool,
     additional_test_case: Iterable[str],
     remove_test_case: Iterable[str],
+    commit: bool,
 ):
     config.update_verbosity(verbose)
     t = PackageTemplater.from_existing(config, Path(package_path))
@@ -613,7 +845,7 @@ def package_update(
     test_cases.extend(additional_test_case)
     t.test_cases = [tc for tc in test_cases if tc not in remove_test_case]
 
-    t.update()
+    t.update(commit=commit)
 
 
 @package.command(name="compile", short_help="Compile a config package standalone")
@@ -691,7 +923,10 @@ def package_compile(
     default="",
 )
 @click.option(
-    "--dry-run", is_flag=True, help="Don't create or update PRs", default=False
+    "--dry-run",
+    is_flag=True,
+    help="Don't commit rendered changes, or create or update PRs",
+    default=False,
 )
 @click.option(
     "--pr-branch",
@@ -737,7 +972,15 @@ def package_sync(
     config.update_verbosity(verbose)
     config.github_token = github_token
 
-    sync_packages(config, Path(package_list), dry_run, pr_branch, pr_label)
+    sync_dependencies(
+        config,
+        Path(package_list),
+        dry_run,
+        pr_branch,
+        pr_label,
+        Package,
+        PackageTemplater,
+    )
 
 
 @commodore.group(short_help="Interact with a Commodore inventory")
