@@ -20,6 +20,18 @@ class Component:
     _dir: P
     _sub_path: str
 
+    @classmethod
+    def clone(cls, cfg, clone_url: str, name: str, version: str = "master"):
+        cdep = cfg.register_dependency_repo(clone_url)
+        c = Component(
+            name,
+            cdep,
+            directory=component_dir(cfg.work_dir, name),
+            version=version,
+        )
+        c.checkout()
+        return c
+
     # pylint: disable=too-many-arguments
     def __init__(
         self,
@@ -53,7 +65,20 @@ class Component:
     @property
     def repo(self) -> GitRepo:
         if not self._repo:
-            self._repo = GitRepo(None, self._dir)
+            if self._dependency:
+                dep_repo = self._dependency.bare_repo
+                author_name = dep_repo.author.name
+                author_email = dep_repo.author.email
+            else:
+                # Fall back to author detection if we don't have a dependency
+                author_name = None
+                author_email = None
+            self._repo = GitRepo(
+                None,
+                self._dir,
+                author_name=author_name,
+                author_email=author_email,
+            )
         return self._repo
 
     @property
@@ -101,6 +126,10 @@ class Component:
     def target_directory(self) -> P:
         return self._dir / self._sub_path
 
+    @property
+    def target_dir(self) -> P:
+        return self.target_directory
+
     @property
     def class_file(self) -> P:
         return self.target_directory / "class" / f"{self.name}.yml"
