@@ -22,6 +22,10 @@ class RefError(ValueError):
     pass
 
 
+class MergeConflict(ValueError):
+    pass
+
+
 CommitInfo = namedtuple("CommitInfo", ["commit", "branch", "tag"])
 
 
@@ -139,6 +143,7 @@ def _process_diff(change_type: str, change, diff_func: DiffFunc) -> Iterable[str
 
 class GitRepo:
     _repo: Repo
+    _author: Optional[Actor]
 
     @classmethod
     def clone(cls, repository_url: str, directory: Path, cfg):
@@ -187,10 +192,9 @@ class GitRepo:
         if remote:
             self.remote = remote
 
-        if author_name and author_email:
-            self._author = Actor(author_name, author_email)
-        else:
-            self._author = Actor.committer(self._repo.config_reader())
+        self._author = None
+        self._author_name = author_name
+        self._author_email = author_email
 
         if config:
             self._debug = config.debug
@@ -238,10 +242,10 @@ class GitRepo:
     @property
     def _author_env(self) -> dict[str, str]:
         return {
-            Actor.env_author_name: self._author.name or "",
-            Actor.env_author_email: self._author.email or "",
-            Actor.env_committer_name: self._author.name or "",
-            Actor.env_committer_email: self._author.email or "",
+            Actor.env_author_name: self.author.name or "",
+            Actor.env_author_email: self.author.email or "",
+            Actor.env_committer_name: self.author.name or "",
+            Actor.env_committer_email: self.author.email or "",
         }
 
     @property
@@ -255,6 +259,23 @@ class GitRepo:
         null_tree_sha = hashlib.sha1(b"tree 0\0").hexdigest()  # nosec
         return self._repo.tree(null_tree_sha)
 
+    @property
+    def author(self) -> Actor:
+        if not self._author:
+            if self._author_name and self._author_email:
+                self._author = Actor(self._author_name, self._author_email)
+            else:
+                try:
+                    self._author = Actor.committer(self._repo.config_reader())
+                except KeyError:
+                    # Handle case where UID-based user info fallback doesn't work
+                    click.echo(
+                        " > Can't determine author information, falling back to "
+                        + "`Commodore <commodore@syn.tools>`"
+                    )
+                    self._author = Actor("Commodore", "commodore@syn.tools")
+        return self._author
+
     def _remote_prefix(self) -> str:
         """
         Find prefix of Git remote, will usually be 'origin/'.
@@ -371,7 +392,9 @@ class GitRepo:
         The heavy work is generally done by `_migrate_to_worktree()`,
         `_update_worktree_remote()` or `checkout()`.
         """
-        wtr = GitRepo(None, worktree)
+        wtr = GitRepo(
+            None, worktree, author_name=self.author.name, author_email=self.author.email
+        )
         if not wtr.repo.has_separate_working_tree():
             # If the worktree's common dir is stored in the repository working tree
             # root, we're migrating from a non-worktree checkout to a worktree checkout.
@@ -454,7 +477,14 @@ class GitRepo:
                 continue
             k, v = line.split(" ")
             if k == "worktree":
-                worktrees.append(GitRepo(None, Path(v)))
+                worktrees.append(
+                    GitRepo(
+                        None,
+                        Path(v),
+                        author_name=self.author.name,
+                        author_email=self.author.email,
+                    )
+                )
 
         return worktrees
 
@@ -501,12 +531,22 @@ class GitRepo:
         except BadName as e:
             raise RefError(f"Revision '{version}' not found in repository") from e
 
+    def _check_conflicts(self):
+        """Check for conflicts in index. Raise `MergeConflict` for the first conflict
+        found."""
+        for (path, blobs) in self.repo.index.unmerged_blobs().items():
+            for stage, b in blobs:
+                if stage != 0:
+                    raise MergeConflict(path)
+
     def stage_all(self, diff_func: DiffFunc = _default_difffunc) -> tuple[str, bool]:
         """Stage all changes.
         This method currently doesn't handle hidden files correctly.
 
         This method returns a tuple containing the colorized diff of the staged changes
         and a boolean indicating whether any changes were staged.
+
+        The method can raise `MergeConflict` if staged changes contain merge conflicts.
         """
         index = self._repo.index
 
@@ -521,6 +561,9 @@ class GitRepo:
 
         # Stage all remaining changes
         index.add("*")
+
+        self._check_conflicts()
+
         # Compute diff of all changes
         try:
             diff = index.diff(self._repo.head.commit)
@@ -543,11 +586,13 @@ class GitRepo:
         return "\n".join(difftext), changed
 
     def stage_files(self, files: Sequence[str]):
-        """Add provided list of files to index."""
+        """Add provided list of files to index.
+        Can raise `MergeConflict` if staged changes contain merge conflicts."""
         self._repo.index.add(files)
+        self._check_conflicts()
 
     def commit(self, commit_message: str, amend=False):
-        author = self._author
+        author = self.author
 
         if self._trace:
             click.echo(f' > Using "{author.name} <{author.email}>" as commit author')
